| norm_factor | R Documentation |
Calculate normalisation factor
norm_factor(
data,
method = c("DESeq", "TMM", "RLE", "UQ", "none"),
norm.data = FALSE
)
data |
a data frame with gene x replicate format |
method |
differential analysis method |
norm.data |
a logical indicating whether normalise data or not |
a list with normalisation factor and normalised data if norm.data
is TRUE otherwise an vector of normalisation factor
## data set from R package 'pasilla'
dn <- system.file("extdata/pasilla_gene_counts.tsv", package = "rnaseqdea")
data <- read.table(dn, header = TRUE, row.names = 1, quote = "", comment.char = "")
keep <- rowSums(data) > 6000
data <- data[keep, ]
res <- norm_factor(data, norm.data = TRUE)
res$nf
head(res$norm.data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.