rna_seq_stats: Get group stats of normalised RNA-Seq data

View source: R/rnaseqdea.R

rna_seq_statsR Documentation

Get group stats of normalised RNA-Seq data

Description

Get group stats of normalised RNA-Seq data

Usage

rna_seq_stats(mat, grp, nf, method = "mean")

Arguments

mat

raw count data with gene x replicate format

grp

group information

nf

normalisation factor

method

data centre function

Details

The summary is based on the normalised data, excluding p-values and their corrections. The p-values are computed by different modelling methods such as DEseq2 and edgeR.

Value

a list including stats summary and normalised data set

Examples

## data set from R package 'pasilla' 
dn <- system.file("extdata/pasilla_gene_counts.tsv", package = "rnaseqdea")
data <- read.table(dn, header = TRUE, row.names = 1, quote = "", comment.char = "")
keep <- rowSums(data) > 6000
data <- data[keep, ]
cls <- c("untreated", "untreated", "untreated", "untreated", 
         "treated", "treated", "treated")
cls <- as.factor(cls)

## get the normalisation factor
nf <- norm_factor(data)

## get summary on normalised data
res <- rna_seq_stats(data,grp = cls, nf = nf)
names(res)
head(res$stats)

wanchanglin/rnaseqdea documentation built on June 2, 2025, 1:05 a.m.