rnaseqdea-package: rnaseqdea: RNA-Seq Differential Expression Analysis...

rnaseqdea-packageR Documentation

rnaseqdea: RNA-Seq Differential Expression Analysis (rnaseqdea)

Description

rnaseqdea provides functions for RNA-Seq differential expression analysis. It implements wrapper functions to call differential statistical models to perform analysis. This package also provides a unified normalisation methods for all used modelling methods. Some plots are implemented for these modelling.

Wrapper functions for statistical analysis methods

  • DESeq2

  • edgeR

  • NBPSeq

  • EBSeq

  • NOISeq

  • SAMseq

  • voom+limma

  • TSPM

  • hypothesis testing

Normalisation methods

  • Normal factor: DESeq, TMM, RLE, UQ. Use for modelling.

  • Variance stabilizing transformation (VST) and Regularized log transformation (RLT) implemented in package DESeq2. Use for the classification and visualisation.

Plots

  • MA plot

  • Volcano plot

  • Histogram of p-values

  • PCA plot

  • MDS plot

  • Boxplot

See Also

Useful links:


wanchanglin/rnaseqdea documentation built on June 2, 2025, 1:05 a.m.