| vst_rlt_tr | R Documentation |
Transform count data. The transformed data can be used in visualisation and classification.
vst_rlt_tr(data, method = c("vst", "rlt"), ...)
data |
a data frame with gene x replicate format |
method |
two normalisation method |
... |
further parameters to |
normalised data
## data set from R package 'pasilla'
dn <- system.file("extdata/pasilla_gene_counts.tsv", package = "rnaseqdea")
data <- read.table(dn, header = TRUE, row.names = 1, quote = "", comment.char = "")
res <- vst_rlt_tr(data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.