| rna_seq_stats | R Documentation |
Get group stats of normalised RNA-Seq data
rna_seq_stats(mat, grp, nf, method = "mean")
mat |
raw count data with gene x replicate format |
grp |
group information |
nf |
normalisation factor |
method |
data centre function |
The summary is based on the normalised data, excluding p-values
and their corrections. The p-values are computed by different modelling
methods such as DEseq2 and edgeR.
a list including stats summary and normalised data set
## data set from R package 'pasilla'
dn <- system.file("extdata/pasilla_gene_counts.tsv", package = "rnaseqdea")
data <- read.table(dn, header = TRUE, row.names = 1, quote = "", comment.char = "")
keep <- rowSums(data) > 6000
data <- data[keep, ]
cls <- c("untreated", "untreated", "untreated", "untreated",
"treated", "treated", "treated")
cls <- as.factor(cls)
## get the normalisation factor
nf <- norm_factor(data)
## get summary on normalised data
res <- rna_seq_stats(data,grp = cls, nf = nf)
names(res)
head(res$stats)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.